@@ -22,6 +22,11 @@ use crate::data::{output, output::ChunkId};
 ///
 /// ## Discussion
 ///
+/// ### Caches
+///
+/// `make_cache` is only suitable for speeding up cache access of blobs as these are not looked up during counting anymore - it only
+/// sees trees as only these are needed for traversal/object counting.
+///
 /// ### Advantages
 ///
 /// * Begins writing immediately and supports back-pressure.
@@ -62,9 +67,7 @@ where
     let chunks = util::ChunkRanges::new(chunk_size, counts.len());
     {
         let progress = Arc::new(parking_lot::Mutex::new(progress.add_child("resolving")));
-        progress
-            .lock()
-            .init(Some(counts.len()), git_features::progress::count("counts"));
+        progress.lock().init(None, git_features::progress::count("counts"));
         let enough_counts_present = counts.len() > 4_000;
         let start = std::time::Instant::now();
         parallel::in_parallel_if(
@@ -205,6 +208,7 @@ where
                                                 .expect("pack used for counts is still available")
                                         });
                                         debug_assert_eq!(*cached_pack_id, pack_id);
+                                        stats.ref_delta_objects += 1;
                                         cache
                                             .binary_search_by_key(&base_offset, |e| e.0)
                                             .ok()
@@ -338,6 +342,8 @@ mod types {
         /// The amount of base or delta objects that could be copied directly from the pack. These are cheapest as they
         /// only cost a memory copy for the most part.
         pub objects_copied_from_pack: usize,
+        /// The amount of objects that ref to their base as ref-delta, an indication for a thin back being created.
+        pub ref_delta_objects: usize,
     }
 
     impl Outcome {
@@ -347,11 +353,13 @@ mod types {
                 decoded_and_recompressed_objects: decoded_objects,
                 missing_objects,
                 objects_copied_from_pack,
+                ref_delta_objects,
             }: Self,
         ) {
             self.decoded_and_recompressed_objects += decoded_objects;
             self.missing_objects += missing_objects;
             self.objects_copied_from_pack += objects_copied_from_pack;
+            self.ref_delta_objects += ref_delta_objects;
         }
     }
 
@@ -377,8 +385,7 @@ mod types {
         /// If set, the resulting back can have deltas that refer to an object which is not in the pack. This can happen
         /// if the initial counted objects do not contain an object that an existing packed delta refers to, for example, because
         /// it wasn't part of the iteration, for instance when the iteration was performed on tree deltas or only a part of the
-        /// commit graph. Please note that thin packs are not valid packs when stored on disk, thus they are only valid for packs
-        /// that are being send over the wire.
+        /// commit graph. Please note that thin packs are not valid packs at rest, thus they are only valid for packs in transit.
         ///
         /// If set to false, delta objects will be decompressed and recompressed as base objects.
         pub allow_thin_pack: bool,
